@@ -1,4 +1,5 @@
 import logging
+import sys
 
 
 def init_logging():
@@ -6,7 +7,7 @@ def init_logging():
     # use 'airtest' as root logger name to prevent changing other modules' logger
     logger = logging.getLogger("yyweaknet")
     logger.setLevel(logging.INFO)
-    handler = logging.StreamHandler()
+    handler = logging.StreamHandler(sys.stdout)
     formatter = logging.Formatter(
         fmt='[%(asctime)s][%(levelname)s]<%(name)s> %(message)s',
         datefmt='%H:%M:%S'
