@@ -1,9 +1,8 @@
-import logging
 import traceback
-
+from yyweaknet import logger as logging
 import requests
 
-logger = logging.getLogger("main")
+logger = logging.get_logger("yyweaknet")
 
 
 class STFServer(object):
