@@ -2,10 +2,10 @@ import re
 
 import requests
 import time
-import logging
+from yyweaknet import logger as logging
 from yyweaknet.stf import STFServer
 
-logger = logging.getLogger("main")
+logger = logging.get_logger("yyweaknet")
 
 
 class WeakNetworkConfig(object):
